@@ -17,11 +17,11 @@ Test::Mock::Redis - use in place of Redis for unit testing
 
 =head1 VERSION
 
-Version 0.15
+Version 0.16
 
 =cut
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 =head1 SYNOPSIS
 
@@ -442,6 +442,16 @@ sub lpushx {
     return scalar @{ $self->_stash->{$key} };
 }
 
+sub rpoplpush {
+    my ( $self, $source_key, $destination_key ) = @_;
+
+    my $popped_element = $self->rpop( $source_key ) or return;
+
+    $self->lpush( $destination_key, $popped_element );
+
+    return $popped_element;
+}
+
 sub llen {
     my ( $self, $key ) = @_;
 
@@ -1149,6 +1159,8 @@ The following people have contributed to I<Test::Mock::Redis>:
 
 =item * Karen Etheridge
 
+=item * Keith Broughton
+
 =item * Kevin Goess
 
 =item * Neil Bowers
